import _extends from "@babel/runtime/helpers/extends";
import { getTransformValue } from './transform';
import remark from 'remark';
import { FUNNAME_PREFIX } from '../';

/** 转换 代码*/
export var getProcessor = source => {
  try {
    var child = remark.parse(source);
    return child.children;
  } catch (err) {
    console.warn(err);
  }
};
/**
 * ```js
 * 'mdx:preview' => ''  // Empty
 * 'mdx:preview:demo12' => 'demo12' // return meta id => 'demo12'
 * ```
 * @param meta string
 * @returns string?
 */

export var getMetaId = function getMetaId(meta) {
  if (meta === void 0) {
    meta = '';
  }

  var [metaRaw = ''] = /mdx:(.[\w|:]+)/i.exec(meta) || [];
  return metaRaw.replace(/^mdx:preview:?/, '');
};
/**
 * ```js
 * isMeta('mdx:preview') => true
 * isMeta('mdx:preview:demo12') => true
 * isMeta('mdx:preview--demo12') => false
 * ```
 * @param meta
 * @returns boolean
 */

export var isMeta = function isMeta(meta) {
  if (meta === void 0) {
    meta = '';
  }

  return meta && meta.includes('mdx:preview');
};
/** 获取需要渲染的代码块 **/

export var getCodeBlock = function getCodeBlock(child, opts) {
  if (opts === void 0) {
    opts = {};
  }

  var {
    lang = ['jsx', 'tsx']
  } = opts; // 获取渲染部分

  var codeBlock = {};

  try {
    child.forEach(item => {
      if (item && item.type === 'code' && lang.includes(item.lang)) {
        var line = item.position.start.line;
        var metaId = getMetaId(item.meta);

        if (isMeta(item.meta)) {
          var name = metaId || line;
          var funName = "" + FUNNAME_PREFIX + name;
          var returnCode = getTransformValue(item.value, funName + "." + lang, opts);
          codeBlock[name] = {
            name,
            code: returnCode,
            language: item.lang,
            value: item.value
          };
        }
      }
    });
  } catch (err) {
    console.warn(err);
  }

  return codeBlock;
};
/**
 * `mdCodeModulesLoader` method for adding `markdown-react-code-preview-loader` to webpack config.
 * @param {webpack.Configuration} config webpack config
 * @param {string[]} lang Parsing language
 * @param {Options} option Loader Options
 * @returns {webpack.Configuration}
 */

export var mdCodeModulesLoader = function mdCodeModulesLoader(config, lang, option) {
  if (option === void 0) {
    option = {};
  }

  config.module.rules.forEach(ruleItem => {
    if (typeof ruleItem === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [{
            loader: 'markdown-react-code-preview-loader',
            options: _extends({
              lang
            }, option)
          }]
        });
      }
    }
  });
  return config;
};
//# sourceMappingURL=index.js.map