"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mdCodeModulesLoader = exports.isMeta = exports.getProcessor = exports.getMetaId = exports.getCodeBlock = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _transform = require("./transform");

var _remark = _interopRequireDefault(require("remark"));

var _ = require("../");

/** 转换 代码*/
var getProcessor = function getProcessor(source) {
  try {
    var child = _remark["default"].parse(source);

    return child.children;
  } catch (err) {
    console.warn(err);
  }
};
/**
 * ```js
 * 'mdx:preview' => ''  // Empty
 * 'mdx:preview:demo12' => 'demo12' // return meta id => 'demo12'
 * ```
 * @param meta string
 * @returns string?
 */


exports.getProcessor = getProcessor;

var getMetaId = function getMetaId() {
  var meta = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  var _ref = /mdx:(.[\w|:]+)/i.exec(meta) || [],
      _ref2 = (0, _slicedToArray2["default"])(_ref, 1),
      _ref2$ = _ref2[0],
      metaRaw = _ref2$ === void 0 ? '' : _ref2$;

  return metaRaw.replace(/^mdx:preview:?/, '');
};
/**
 * ```js
 * isMeta('mdx:preview') => true
 * isMeta('mdx:preview:demo12') => true
 * isMeta('mdx:preview--demo12') => false
 * ```
 * @param meta
 * @returns boolean
 */


exports.getMetaId = getMetaId;

var isMeta = function isMeta() {
  var meta = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  return meta && meta.includes('mdx:preview');
};
/** 获取需要渲染的代码块 **/


exports.isMeta = isMeta;

var getCodeBlock = function getCodeBlock(child) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var _opts$lang = opts.lang,
      lang = _opts$lang === void 0 ? ['jsx', 'tsx'] : _opts$lang; // 获取渲染部分

  var codeBlock = {};

  try {
    child.forEach(function (item) {
      if (item && item.type === 'code' && lang.includes(item.lang)) {
        var line = item.position.start.line;
        var metaId = getMetaId(item.meta);

        if (isMeta(item.meta)) {
          var name = metaId || line;
          var funName = "".concat(_.FUNNAME_PREFIX).concat(name);
          var returnCode = (0, _transform.getTransformValue)(item.value, "".concat(funName, ".").concat(lang), opts);
          codeBlock[name] = {
            name: name,
            code: returnCode,
            language: item.lang,
            value: item.value
          };
        }
      }
    });
  } catch (err) {
    console.warn(err);
  }

  return codeBlock;
};
/**
 * `mdCodeModulesLoader` method for adding `markdown-react-code-preview-loader` to webpack config.
 * @param {webpack.Configuration} config webpack config
 * @param {string[]} lang Parsing language
 * @param {Options} option Loader Options
 * @returns {webpack.Configuration}
 */


exports.getCodeBlock = getCodeBlock;

var mdCodeModulesLoader = function mdCodeModulesLoader(config, lang) {
  var option = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  config.module.rules.forEach(function (ruleItem) {
    if ((0, _typeof2["default"])(ruleItem) === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [{
            loader: 'markdown-react-code-preview-loader',
            options: (0, _objectSpread2["default"])({
              lang: lang
            }, option)
          }]
        });
      }
    }
  });
  return config;
};

exports.mdCodeModulesLoader = mdCodeModulesLoader;
//# sourceMappingURL=index.js.map